@@ -240,7 +240,7 @@ static void show_status(FILE *fp) {
 
 static int run_command(char *line, FILE *fp, t_config *config) {
 	char *cmd, *param, *param2;
-	t_ipv4 ip;
+	t_ip_addr ip;
 	int retval = 0, time, id, count;
 	
 	split_string(line, &cmd, &param, ' ');
@@ -256,7 +256,7 @@ static int run_command(char *line, FILE *fp, t_config *config) {
 			}
 			if (parse_ip(param, &ip) == -1) {
 				fprintf(fp, "  invalid IP!\n");
-			} else switch (count = ban_ip(ip, time, config->kick_on_ban)) {
+			} else switch (count = ban_ip(&ip, time, config->kick_on_ban)) {
 				case -1:
 					fprintf(fp, "  error while banning!\n");
 					break;
@@ -300,7 +300,7 @@ static int run_command(char *line, FILE *fp, t_config *config) {
 				fprintf(fp, "  client not found!\n");
 			}
 		} else if (parse_ip(param, &ip) != -1) {
-			fprintf(fp, "  %d clients have been kicked\n", kick_ip(ip));
+			fprintf(fp, "  %d clients have been kicked\n", kick_ip(&ip));
 		} else if (strcmp(param, "yourself") == 0) {
 			fprintf(fp, "  I can't. I'm a computer.\n");
 		} else if (strcmp(param, "me") == 0) {
@@ -331,7 +331,7 @@ static int run_command(char *line, FILE *fp, t_config *config) {
 			fprintf(fp, "  %d IPs have been unbanned\n", unban_ip(0));
 		} else if (parse_ip(param, &ip) == -1) {
 			fprintf(fp, "  invalid IP!\n");
-		} else if (unban_ip(ip) == 1) {
+		} else if (unban_ip(&ip) == 1) {
 			fprintf(fp, "  IP has been unbanned\n");
 		} else {
 			fprintf(fp, "  IP not found!\n");
