@@ -11,8 +11,4 @@
 
 #define TIMER_OFF -1
 
-#define ip_index(ip) (ip & 255)
-
-typedef unsigned long t_ipv4;
-
 #endif
