@@ -162,7 +162,7 @@ t_cgi_type check_target_is_cgi(t_session *session) {
 	if ((session->fcgi_server = fcgi_server_match(session->config->fcgi_server, &(session->host->fast_cgi), session->extension)) != NULL) {
 		session->cgi_type = fastcgi;
 	} else if (in_charlist(session->extension, &(session->config->cgi_extension))) {
-		session->cgi_type = program;
+		session->cgi_type = binary;
 	} else {
 		cgi = session->config->cgi_handler;
 		while (cgi != NULL) {
@@ -804,9 +804,7 @@ int serve_client(t_session *session) {
 	int result, length;
 	char *search, *conffile, *qmark;
 	t_host *host_record;
-	bool file_not_found = false;
 	t_access access;
-	t_fsbool is_dir;
 #ifdef HAVE_TOOLKIT
 	int i;
 	char *new_uri;
@@ -971,14 +969,6 @@ int serve_client(t_session *session) {
 				if ((result = get_path_info(session)) != 200) {
 					return result;
 				}
-			} else if ((search = strrchr(session->file_on_disk, '/')) != NULL) {
-				*search = '\0';
-				is_dir = is_directory(session->file_on_disk);
-				*search = '/';
-
-				if (is_dir == no) {
-					return 404;
-				}
 			}
 			break;
 		case no_access:
@@ -995,14 +985,6 @@ int serve_client(t_session *session) {
 						}
 					}
 				}
-
-				if (session->accept_gzip == false) {
-					if (session->host->fast_cgi.size == 0) {
-						return 404;
-					} else {
-						file_not_found = true;
-					}
-				}
 			}
 	}
 
@@ -1010,8 +992,6 @@ int serve_client(t_session *session) {
 	if (*(session->file_on_disk + length - 1) == '/') {
 		if (session->uri_is_dir) {
 			strcpy(session->file_on_disk + length, session->host->start_file);
-		} else {
-			return 404;
 		}
 	} else if (session->uri_is_dir) {
 		return 301;
@@ -1027,9 +1007,6 @@ int serve_client(t_session *session) {
 
 	if ((session->request_method != PUT) && (session->request_method != DELETE)) {
 		check_target_is_cgi(session);
-		if (file_not_found && (session->cgi_type != fastcgi)) {
-			return 404;
-		}
 	}
 
 	switch (session->request_method) {
