@@ -54,6 +54,10 @@ int set_to_localhost(t_ip_addr *ip_addr) {
 }
 
 int parse_ip(char *str, t_ip_addr *ip_addr) {
+	if ((str == NULL) || (ip_addr == NULL)) {
+		return -1;
+	}
+
 	if (inet_pton(AF_INET, str, ip_addr->value) > 0) {
 		ip_addr->family = AF_INET;
 		ip_addr->size = IPv4_LEN;
@@ -73,12 +77,13 @@ int parse_ip(char *str, t_ip_addr *ip_addr) {
 }
 
 unsigned char index_by_ip(t_ip_addr *ip) {
-	unsigned char index;
+	unsigned char index = 0;
 	int i;
 
-	index = 0;
-	for (i = 0; i < ip->size; i++) {
-		index += ip->value[i];
+	if (ip != NULL) {
+		for (i = 0; i < ip->size; i++) {
+			index += ip->value[i];
+		}
 	}
 
 	return index;
@@ -111,7 +116,9 @@ bool same_ip(t_ip_addr *ip1, t_ip_addr *ip2) {
 int apply_netmask(t_ip_addr *ip, int mask) {
 	int byte;
 
-	if (ip->family == AF_INET) {
+	if (ip == NULL) {
+		return -1;
+	} else if (ip->family == AF_INET) {
 		byte = IPv4_LEN - 1;
 		mask = (8 * IPv4_LEN) - mask;
 #ifdef HAVE_IPV6
@@ -159,6 +166,10 @@ bool ip_in_subnet(t_ip_addr *ip, t_ip_addr *subnet, int mask) {
 int parse_ip_port(char *line, t_ip_addr *ip, int *port) {
 	char *s_ip, *s_port, sep = '?';
 
+	if ((line == NULL) || (ip == NULL) || (port == NULL)) {
+		return -1;
+	}
+
 #ifdef HAVE_IPV6
 	if (split_string(line, &s_ip, &s_port, ']') == 0) {
 		if ((*s_ip != '[') || (*s_port != ':')) {
