@@ -168,7 +168,7 @@ bool valid_uri(char *uri) {
 	}
 
 	while (*(++uri) != '\0') {
-		if (*uri < 32) {
+		if ((unsigned char)*uri < 32) {
 			return false;
 		}
 	}
@@ -193,7 +193,7 @@ static short hex_to_int(char c) {
 /* Encode a string to an URL encoded one
  */
 static bool char_needs_encoding(char c) {
-	return (c <= 31) || (strchr(" \"#%'<>", c) != NULL) || (c >= 126);
+	return (c <= 31) || (strchr("\"#%'<>", c) != NULL) || (c >= 126);
 }
 int url_encode(char *str, char **encoded) {
 	char *c, *e;
@@ -217,7 +217,9 @@ int url_encode(char *str, char **encoded) {
 	c = str;
 	e = *encoded;
 	while (*c != '\0') {
-		if (char_needs_encoding(*c)) {
+		if (*c == ' ') {
+			*e = '+';
+		} else if (char_needs_encoding(*c)) {
 			sprintf(e, "%%%02hhx", *c);
 			e += 2;
 		} else {
@@ -242,7 +244,9 @@ void url_decode(char *str) {
 	}
 
 	while (*str != '\0') {
-		if (*str == '%') {
+		if (*str == '+') {
+			*str = ' ';
+		} else if (*str == '%') {
 			if ((high = hex_to_int(*(str + 1))) != -1) {
 				if ((low = hex_to_int(*(str + 2))) != -1) {
 					str += 2;
@@ -611,3 +615,33 @@ bool min_strlen(char *str, int n) {
 
 	return true;
 }
+
+int header_to_variable(char *header, char *variable, int size) {
+	char *column;
+	int len, i;
+
+	if ((column = strchr(header, ':')) == NULL) {
+		return -1;
+	}
+	len = column - header;
+	if (len + 6 > size) {
+		return -1;
+	}
+
+	strcpy(variable, "HTTP_");
+
+	for (i = 0; i < len; i++) {
+		if (((header[i] >= 'A') && (header[i] <= 'Z')) || ((header[i] >= '0') && (header[i] <= '9'))) {
+			variable[i + 5] = header[i];
+		} else if ((header[i] >= 'a') && (header[i] <= 'z')) {
+			variable[i + 5] = header[i] - 32;
+		} else if (header[i] == '-') {
+			variable[i + 5] = '_';
+		} else {
+			return -1;
+		}
+	}
+	variable[len + 5] = '\0';
+
+	return 0;
+}
