@@ -21,6 +21,12 @@
 #define MAX_LOG_DELAY_TIMER 10
 #define LOGFILE_OPEN_TIME   30
 
+#ifdef CYGWIN
+#define EOL "\r\n"
+#else
+#define EOL "\n"
+#endif
+
 pthread_mutex_t accesslog_mutex;
 static int delay_timer = 0;
 
@@ -77,7 +83,7 @@ void log_pid(t_config *config, pid_t pid) {
 		fprintf(fp, "%d\n", (int)pid);
 		fclose(fp);
 		if (chmod(config->pidfile, S_IRUSR | S_IWUSR | S_IRGRP) == -1) {
-			fprintf(stderr, "Warning: can't chmod PID file %s. Make sure it's only writable for root!", config->pidfile);
+			fprintf(stderr, "Warning: can't chmod PID file %s. Make sure it's only writable for root!\n", config->pidfile);
 		}
 	} else {
 		fprintf(stderr, "Warning: can't write PID file %s.\n", config->pidfile);
@@ -92,7 +98,7 @@ void log_string(char *logfile, char *mesg) {
 
 	if ((fp = fopen(logfile, "a")) != NULL) {
 		print_timestamp(str);
-		fprintf(fp, "%s%s\n", str, mesg);
+		fprintf(fp, "%s%s"EOL, str, mesg);
 		fclose(fp);
 	}
 }
@@ -121,9 +127,9 @@ void log_file_error(t_session *session, char *file, char *mesg) {
 		print_timestamp(str);
 		print_ip_address(str + strlen(str), &(session->ip_address));
 		if (file != NULL) {
-			fprintf(fp, "%s%s|%s\n", str, file, mesg);
+			fprintf(fp, "%s%s|%s"EOL, str, file, mesg);
 		} else {
-			fprintf(fp, "%s%s\n", str, mesg);
+			fprintf(fp, "%s%s"EOL, str, mesg);
 		}
 		fclose(fp);
 	}
@@ -261,7 +267,7 @@ void log_request(t_session *session, int code) {
 			*(session->host->access_fp) = fopen(session->host->access_logfile, "a");
 		}
 		if (*(session->host->access_fp) != NULL) {
-			fprintf(*(session->host->access_fp), "%s\n", str);
+			fprintf(*(session->host->access_fp), "%s"EOL, str);
 			fflush(*(session->host->access_fp));
 		}
 		pthread_mutex_unlock(&accesslog_mutex);
@@ -290,7 +296,7 @@ void log_garbage(t_session *session) {
 		if ((fp = fopen(session->config->garbage_logfile, "a")) != NULL) {
 			print_ip_address(str, &(session->ip_address));
 			print_timestamp(str + strlen(str));
-			fprintf(fp, "%s%s\n", str, session->request);
+			fprintf(fp, "%s%s"EOL, str, session->request);
 			fclose(fp);
 		}
 	}
@@ -335,7 +341,7 @@ void log_cgi_error(t_session *session, char *mesg) {
 		if ((fp = fopen(session->host->error_logfile, "a")) != NULL) {
 			print_timestamp(str);
 			print_ip_address(str + strlen(str), &(session->ip_address));
-			fprintf(fp, "%s%s|%s\n", str, session->file_on_disk, secure_string(mesg));
+			fprintf(fp, "%s%s|%s"EOL, str, session->file_on_disk, secure_string(mesg));
 			fclose(fp);
 		}
 	}
