@@ -99,27 +99,28 @@ int read_mimetypes(char *configfile, t_mimetype **mime) {
 
 /* Return the mimetype of a file.
  */
-char *get_mimetype(char *filename, t_mimetype *mime) {
-	char *ext, *ext_lower, *result = default_mimetype;
+char *get_mimetype(char *extension, t_mimetype *mime) {
+	char *ext_lower, *result = default_mimetype;
 	t_extension *w_ext = NULL;
 
 	/* Convert file extension to mimetype.
 	 */ 
-	if (filename != NULL) {
-		if ((ext = strrchr(filename, '.')) != NULL) {
-			if ((ext_lower = strlower(strdup(++ext))) != NULL) {
-				w_ext = mime->extension;
-				while (w_ext != NULL) {
-					if (strcmp(ext_lower, w_ext->name) == 0) {
-						result = w_ext->mimename->name;
-						break;
-					}
-					w_ext = w_ext->next;
-				}
-				free(ext_lower);
-			}
-		}
+	if (extension == NULL) {
+		return NULL;
+	} else if ((ext_lower = strlower(strdup(extension))) == NULL) {
+		return NULL;
 	}
 
+	w_ext = mime->extension;
+	while (w_ext != NULL) {
+		if (strcmp(ext_lower, w_ext->name) == 0) {
+			result = w_ext->mimename->name;
+			break;
+		}
+		w_ext = w_ext->next;
+	}
+
+	free(ext_lower);
+
 	return result;
 }
