@@ -51,7 +51,9 @@ static int send_to_client(t_session *session, const char *buffer, int size) {
 
 	/* Send buffer to browser.
 	 */
-	if ((buffer == NULL) || (size <= 0)) {
+	if (session->socket_open == false) {
+		return -1;
+	} else if ((buffer == NULL) || (size <= 0)) {
 		return 0;
 	}
 
@@ -205,7 +207,7 @@ int send_header(t_session *session, int code) {
 		return -1;
 	} else if (send_buffer(session, timestr, strlen(timestr)) == -1) {
 		return -1;
-	} else if (strcmp(session->config->server_string, "-") != 0) {
+	} else if (session->config->server_string != NULL) {
 		if (send_buffer(session, hs_server, 8) == -1) {
 			return -1;
 		} else if (send_buffer(session, session->config->server_string, strlen(session->config->server_string)) == -1) {
