@@ -469,13 +469,13 @@ int execute_cgi(t_session *session) {
 	}
 
 #ifdef CYGWIN
-	if ((session->config->platform == windows) && (session->cgi_type == program)) {
+	if ((session->config->platform == windows) && (session->cgi_type == binary)) {
 		chmod(session->file_on_disk, 0755);
 	}
 #endif
 
 	if ((wrap_cgi == false) && (session->cgi_type != fastcgi)) {
-		if (session->cgi_type == program) {
+		if (session->cgi_type == binary) {
 			switch (can_execute(session->file_on_disk, session->config->server_uid, session->config->server_gid, &(session->config->groups))) {
 				case error:
 					log_error(session, "error during CGI preprocess");
@@ -1048,7 +1048,7 @@ int show_index(t_session *session) {
 				break;
 			}
 		} else {
-			if (send_chunk(session, "<style type=\"text/css\">BODY { margin:50px 100px 50px 100px ; background-color:#000008 ; font-family:sans-serif } TABLE.list { width:100% ; border-left:5px solid #8080ff ; border-right:5px solid #8080ff ; border-collapse:collapse } A { color:#900000 ; text-decoration:none } A:visited { color:#404040 } A:hover { color:#ff4040 ; text-decoration:underline } DIV.path { color:#ffffff ; font-size:20px ; text-align:right ; font-weight:bold ; margin-bottom:10px ; margin-right:25px} TR { font-size:12px } TH { background-color:#8080ff } TH.left { width:40px } TH.filename { text-align:left } TH.date { width:150px } TH.size { width:80px ; text-align:right} TH.right { width:30px } TD.left { padding-left:5px } TD.size { text-align:right } TR.line0 { background-color:#e0e0ff } TR.line1 { background-color:#e8e8ff } TR.bottom { background-color:#8080ff ; font-weight:bold } TD.totalsize { text-align:right }</style>\n", 910) == -1) {
+			if (send_chunk(session, "<style type=\"text/css\">body { margin:50px 100px 50px 100px ; background-color:#000008 ; font-family:sans-serif } table.list { width:100% ; border-left:5px solid #8080ff ; border-right:5px solid #8080ff ; border-collapse:collapse } a { color:#900000 ; text-decoration:none } a:visited { color:#404040 } a:hover { color:#ff4040 ; text-decoration:underline } div.path { color:#ffffff ; font-size:20px ; text-align:right ; font-weight:bold ; margin-bottom:10px ; margin-right:25px} tr { font-size:12px } th { background-color:#8080ff } th.left { width:40px } th.filename { text-align:left } th.date { width:150px } th.size { width:80px ; text-align:right} th.right { width:30px } td.left { padding-left:5px } td.size { text-align:right } tr.line0 { background-color:#e0e0ff } tr.line1 { background-color:#e8e8ff } tr.bottom { background-color:#8080ff ; font-weight:bold } td.totalsize { text-align:right }</style>\n", 910) == -1) {
 				break;
 			}
 		}
@@ -1558,8 +1558,18 @@ int handle_delete_request(t_session *session) {
 	/* Delete file
 	 */
 	if (unlink(session->file_on_disk) == -1) {
-		log_error(session, fb_filesystem);
-		return 403;
+		switch (errno) {
+			case EACCES:
+				log_error(session, fb_filesystem);
+				return 403;
+			case ENOENT:
+				return 404;
+			case EISDIR:
+			case ENOTDIR:
+				return 405;
+			default:
+				return 500;
+		}
 	}
 
 	return 204;
