@@ -24,6 +24,11 @@ bool quiet = false;
 
 int read_file(char *config_file, t_line **config, t_line **aliases, bool handle_include);
 
+void mem_error() {
+	fprintf(stderr, "Fatal error while allocating memory.\n");
+	exit(EXIT_FAILURE);
+}
+
 t_line *last_result(t_line *config) {
 	if (config != NULL) {
 		while (config->next != NULL) {
@@ -34,17 +39,17 @@ t_line *last_result(t_line *config) {
 	return config;
 }
 
-int add_result(t_line **config, char *key, char *value, char *file, int linenr) {
+void add_result(t_line **config, char *key, char *value, char *file, int linenr) {
 	t_line *new;
 
 	if (*config == NULL) {
 		if ((new = *config = (t_line*)malloc(sizeof(t_line))) == NULL) {
-			return -1;
+			mem_error();
 		}
 	} else {
 		new = last_result(*config);
 		if ((new->next = (t_line*)malloc(sizeof(t_line))) == NULL) {
-			return -1;
+			mem_error();
 		}
 		new = new->next;
 	}
@@ -54,8 +59,6 @@ int add_result(t_line **config, char *key, char *value, char *file, int linenr)
 	new->value = value;
 	new->file = file;
 	new->linenr = linenr;
-
-	return 0;
 }
 
 t_line *search_key(t_line *config, char *key) {
@@ -66,8 +69,8 @@ t_line *search_key(t_line *config, char *key) {
 			if (config->value == NULL) {
 				printf("'%s' on line %d in '"CONFIG_DIR"/%s' requires a parameter.\n", config->key, config->linenr, config->file);
 				exit(EXIT_FAILURE);
-			} else if (add_result(&result, config->key, config->value, config->file, config->linenr) != 0) {
-				return NULL;
+			} else {
+				add_result(&result, config->key, config->value, config->file, config->linenr);
 			}
 		}
 		config = config->next;
@@ -215,12 +218,14 @@ int read_file(char *config_file, t_line **config, t_line **aliases, bool handle_
 				is_alias = false;
 			}
 
-			data = strdup(data);
+			if ((data = strdup(data)) == NULL) {
+				mem_error();
+			}
 			split_configline(data, &data, &value);
 			if (is_alias) {
-				retval = add_result(aliases, data, value, config_file, linenr);
+				add_result(aliases, data, value, config_file, linenr);
 			} else {
-				retval = add_result(config, strlower(data), value, config_file, linenr);
+				add_result(config, strlower(data), value, config_file, linenr);
 			}
 		}
 
@@ -238,7 +243,9 @@ int read_config_file(char *config_file, t_line **config) {
 	char *new_value;
 	int retval;
 
-	if ((retval = read_file(config_file, config, &aliases, true)) == -1) {
+	if (config_file == NULL) {
+		return -1;
+	} else if ((retval = read_file(config_file, config, &aliases, true)) == -1) {
 		return -1;
 	}
 
@@ -323,12 +330,40 @@ int check_main_config(char *config_dir) {
 	errors += find_duplicates(config, "FastCGIid", config_dir);
 	errors += find_duplicates(config, "ToolkitId", config_dir);
 
+	/* Duplicate hostnames check
+	 */
+	haystack = NULL;
+	needles = needle = search_key(config, "hostname");
+	while (needle != NULL) {
+		if ((rest = strdup(needle->value)) == NULL) {
+			mem_error();
+		}
+		while (rest != NULL) {
+			split_string(rest, &item, &rest, ',');
+			if (in_result(item, haystack) == false) {
+				if ((info = strdup(item)) == NULL) {
+					mem_error();
+				}
+				add_result(&haystack, info, info, needle->file, needle->linenr);
+			} else {
+				printf("Duplicate hostname '%s' found on line %d in '%s/%s'.\n", item, needle->linenr, config_dir, needle->file);
+				errors++;
+			}
+		}
+		free(rest);
+		needle = needle->next;
+	}
+	dispose_result(needles, false);
+	dispose_result(haystack, true);
+
 	/* Binding Id check
 	 */
 	haystack = search_key(config, "bindingid");
 	needles = needle = search_key(config, "requiredbinding");
 	while (needle != NULL) {
-		rest = strdup(needle->value);
+		if ((rest = strdup(needle->value)) == NULL) {
+			mem_error();
+		}
 		while (rest != NULL) {
 			split_string(rest, &item, &rest, ',');
 			if (in_result(item, haystack) == NULL) {
@@ -347,7 +382,9 @@ int check_main_config(char *config_dir) {
 	haystack = search_key(config, "fastcgiid");
 	needles = needle = search_key(config, "fastcgi");
 	while (needle != NULL) {
-		rest = strdup(needle->value);
+		if ((rest = strdup(needle->value)) == false) {
+			mem_error();
+		}
 		while (rest != NULL) {
 			split_string(rest, &item, &rest, ',');
 			if (in_result(item, haystack) == NULL) {
@@ -386,7 +423,9 @@ int check_main_config(char *config_dir) {
 	haystack = search_key(config, "toolkitid");
 	needles = needle = search_key(config, "usetoolkit");
 	while (needle != NULL) {
-		rest = strdup(needle->value);
+		if ((rest = strdup(needle->value)) == NULL) {
+			mem_error();
+		}
 		while (rest != NULL) {
 			split_string(rest, &item, &rest, ',');
 			if (in_result(item, haystack) == NULL) {
@@ -405,7 +444,9 @@ int check_main_config(char *config_dir) {
 	haystack = NULL;
 	needles = needle = search_key(config, "cgiextension");
 	while (needle != NULL) {
-		rest = strdup(needle->value);
+		if ((rest = strdup(needle->value)) == NULL) {
+			mem_error();
+		}
 		while (rest != NULL) {
 			split_string(rest, &item, &rest, ',');
 			if (in_result(item, haystack) == NULL) {
@@ -426,7 +467,9 @@ int check_main_config(char *config_dir) {
 			rest += 2;
 		} else
 #endif
-			rest = strdup(needle->value);
+			if ((rest = strdup(needle->value)) == NULL) {
+				mem_error();
+			}
 		split_string(rest, &info, &rest, ':');
 #ifdef CYGWIN
 		info = needle->value;
